Cheshire3 Objects: ProtocolHandler

|  | ## Cheshire3 Objects: Protocol Handler

Description

A protocol handler is the first object which is encountered in any given operation. The handler acts as a black box which parses the request, does a lot of magic and gives back the response. Of course that magic is simply knowing about the top level of objects within the system and turning the request into a workflow which will collect the information necessary to respond.

Implementations

- srwApacheHandler
  Handles SRW/U protocol via an Apache RequestHandler
- zApacheHandler
  Handles Z39.50 protocol via an Apache ConnectionHandler
- oaiApacheHandler
  Handles the OAI-PMH protocol via an Apache RequestHandler
- cnwHandler
  Example store front application

API

Protocol Handlers do not have a standardised API as they are dependant on the framework in which they're included. Apache based handlers will generally be RequestHandlers, but for binary protocols such as Z39.50 they need to be ConnectionHandlers. An IRC protocol handler, on the other hand, would be entirely different.